#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.agent_based.v2 import (
    CheckPlugin,
    AgentSection,
    DiscoveryResult,
    CheckResult,
    Service,
    check_levels,
    get_value_store,
)

from cmk_addons.plugins.emcunity.lib.utils import *

from cmk.plugins.lib.temperature import *


agent_section_emcunity_dpe = AgentSection(
    name="emcunity_dpe",
    parse_function=parse_emcunity_generic,
)


def _render_celsius_from_string(input: str) -> float:
    # input = 75° F (24° C)
    input = input.split("(")[1]
    input = input.split("°")[0]
    input = float(input)
    return input

def discover_emcunity_dpe(section: dict[str, dict[str, str]]) -> DiscoveryResult:
    for _id, dpe in section.items():
        yield Service(
            item = dpe.get("Name"),
        )

def check_emcunity_dpe(item: str, params: dict, section: dict[str, dict[str, str]]) -> CheckResult:
    for _id, dpe in section.items():
        if dpe.get("Name") == item:
            yield from check_health(dpe.get("Health state"), dpe.get('Health details'))
            power = int(dpe.get('Power (Present)').split(" ")[0])
            yield from check_levels(
                value=power,
                label="Power",
                metric_name="emcunity_dpe_power",
                render_func=lambda x: f"{x} Watts",
            )
            temperature = _render_celsius_from_string(dpe.get("Temperature (Present)", dpe.get("Temperature")))
            yield from check_temperature(
                reading=temperature,
                dev_unit="c",
                unique_name=item,
                value_store=get_value_store,
                params=params,
            )

check_plugin_emcunity_dpe = CheckPlugin(
    name="emcunity_dpe",
    service_name="%s",
    discovery_function=discover_emcunity_dpe,
    check_function=check_emcunity_dpe,
    check_ruleset_name="temperature",
    check_default_parameters={},
)