#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2024  SVA System Vertrieb Alexander GmbH
#                       by leon.buhleier@sva.de

from cmk.agent_based.v2 import (
    CheckPlugin,
    AgentSection,
    get_value_store
)

from cmk_addons.plugins.emcunity.lib.utils import *

from cmk.plugins.lib.df import *

import time


agent_section_emcunity_fs = AgentSection(
    name="emcunity_fs",
    parse_function=parse_emcunity_generic,
)


def _render_emcuntiy_fs_size(size: str) -> float:
    size = size.split(" ")[0]
    size = float(size) / 1024.0**2
    return size

def check_emcunity_fs(item: str, params: dict, section: dict[str, dict[str, str]]) -> CheckResult:
    for _id, fs in section.items():
        if fs.get("Name") == item:
            yield from check_health(fs.get("Health state"), fs.get('Health details'))
            
            filesytem_size = _render_emcuntiy_fs_size(fs.get("Size"))
            filesystem_size_used = _render_emcuntiy_fs_size(fs.get("Size used"))
            free_space = filesytem_size - filesystem_size_used
            yield from df_check_filesystem_single(
                filesystem_size=filesytem_size,
                free_space=free_space,
                inodes_avail=None,
                inodes_total=None,
                mountpoint=item,
                params=params,
                reserved_space=filesystem_size_used,
                this_time=time.time(),
                value_store=get_value_store(),
            )

            yield Result(
                state=State.OK,
                summary=f"Protocol: {fs.get("Protocol")}, Pool: {fs.get("Storage Pool")}"
            )

check_plugin_emcunity_fs = CheckPlugin(
    name="emcunity_fs",
    service_name="Filesystem %s",
    discovery_function=discover_emcunity_generic,
    check_function=check_emcunity_fs,
    check_ruleset_name="filesystem",
    check_default_parameters=EMCUNITY_DEFAULT_PARAMS,
)